@@ -24,6 +24,7 @@ import jwt
 import requests as generic_requests
 
 from snowflake.connector.compat import (urlsplit, OK)
+from snowflake.connector.constants import HTTP_HEADER_USER_AGENT
 from snowflake.connector.errorcode import (
     ER_INVALID_OCSP_RESPONSE,
     ER_INVALID_OCSP_RESPONSE_CODE,
@@ -33,6 +34,7 @@ from snowflake.connector.errorcode import (
     ER_OCSP_FAILED_TO_CONNECT_HOST,
 )
 from snowflake.connector.errors import RevocationCheckError
+from snowflake.connector.network import PYTHON_CONNECTOR_USER_AGENT
 from snowflake.connector.ssd_internal_keys import (
     ocsp_internal_ssd_pub_dep1,
     ocsp_internal_ssd_pub_dep2,
@@ -126,6 +128,8 @@ class SSDPubKey(object):
 
 class OCSPServer(object):
 
+    MAX_RETRY = int(os.getenv('OCSP_MAX_RETRY', '3'))
+
     def __init__(self):
         self.DEFAULT_CACHE_SERVER_URL = "http://ocsp.snowflakecomputing.com"
         '''
@@ -244,8 +248,10 @@ class OCSPServer(object):
             # if any of them is not cache, download the cache file from
             # OCSP response cache server.
             try:
-                OCSPServer._download_ocsp_response_cache(ocsp,
+                retval = OCSPServer._download_ocsp_response_cache(ocsp,
                                                          self.CACHE_SERVER_URL)
+                if not retval:
+                    raise RevocationCheckError(msg="OCSP Cache Server Unavailable.")
                 logger.debug("downloaded OCSP response cache file from %s",
                              self.CACHE_SERVER_URL)
                 logger.debug("# of certificates: %s", len(OCSPCache.CACHE))
@@ -261,18 +267,20 @@ class OCSPServer(object):
         :param url: OCSP response cache server
         :param do_retry: retry if connection fails up to N times
         """
+        headers = {HTTP_HEADER_USER_AGENT: PYTHON_CONNECTOR_USER_AGENT}
         try:
             start_time = time.time()
             logger.debug(
                 "started downloading OCSP response cache file: %s", url)
             with generic_requests.Session() as session:
-                max_retry = 30 if do_retry else 1
+                max_retry = OCSPServer.MAX_RETRY if do_retry else 1
                 sleep_time = 1
                 backoff = DecorrelateJitterBackoff(sleep_time, 16)
                 for attempt in range(max_retry):
                     response = session.get(
                         url,
                         timeout=10,  # socket timeout
+                        headers=headers,
                     )
                     if response.status_code == OK:
                         ocsp.decode_ocsp_response_cache(response.json())
@@ -291,6 +299,8 @@ class OCSPServer(object):
                     logger.error(
                         "Failed to get OCSP response after %s attempt.",
                         max_retry)
+                    return False
+                return True
 
         except Exception as e:
             logger.debug("Failed to get OCSP response cache from %s: %s", url,
@@ -1238,6 +1248,7 @@ class SnowflakeOCSP(object):
         if not ocsp_url:
             raise RevocationCheckError(msg="No OCSP URL found in cert. Cannot perform Certificate Revocation check",
                                        errno=ER_SERVER_CERTIFICATE_UNKNOWN)
+        headers = {HTTP_HEADER_USER_AGENT: PYTHON_CONNECTOR_USER_AGENT}
 
         if not SnowflakeOCSP.SSD.ACTIVATE_SSD and \
                 not OCSPServer.is_enabled_new_ocsp_endpoint():
@@ -1251,11 +1262,10 @@ class SnowflakeOCSP(object):
                 target_url = self.OCSP_CACHE_SERVER.generate_get_url(
                     ocsp_url, b64data)
                 payload = None
-                headers = None
             else:
                 target_url = ocsp_url
                 payload = self.decode_ocsp_request(ocsp_request)
-                headers = {'Content-Type': 'application/ocsp-request'}
+                headers['Content-Type'] = 'application/ocsp-request'
         else:
             actual_method = 'post'
             target_url = self.OCSP_CACHE_SERVER.OCSP_RETRY_URL
@@ -1264,7 +1274,7 @@ class SnowflakeOCSP(object):
                                   'ocsp_request': ocsp_req_enc,
                                   'cert_id': cert_id_enc,
                                   'ocsp_responder_url': ocsp_url})
-            headers = {'Content-Type': 'application/json'}
+            headers['Content-Type'] = 'application/json'
 
         self.debug_ocsp_failure_url = SnowflakeOCSP.create_ocsp_debug_info(
             self, ocsp_request, ocsp_url)
@@ -1275,7 +1285,7 @@ class SnowflakeOCSP(object):
         ret = None
         logger.debug('url: %s', target_url)
         with generic_requests.Session() as session:
-            max_retry = 10 if do_retry else 1
+            max_retry = OCSPServer.MAX_RETRY if do_retry else 1
             sleep_time = 1
             backoff = DecorrelateJitterBackoff(sleep_time, 16)
             for attempt in range(max_retry):
@@ -1636,3 +1646,9 @@ class SnowflakeOCSP(object):
         Human readable Subject name
         """
         raise NotImplementedError
+
+    def is_valid_time(self, cert_id, ocsp_response):
+        """
+        Check whether ocsp_response is in valid time range
+        """
+        raise NotImplementedError
